@@ -31,32 +31,31 @@ use SDL::Event;
 use SDL::Events; 
 
 my $app = SDLx::App->new(
-        height => 120,
-        width  => 480,
-        depth  => 16,
-        title  => 'Sound example',
-);
+		height => 120,
+		width  => 480,
+		depth  => 16,
+		title  => 'Sound example',
+		);
 my $snd = SDLx::Sound->new();
 
 # load and play a sound
 my $play = $snd->play('test/data/sample.wav');
 
 # pause or resume on keydown 
-my %actions = (
-        SDL_QUIT()    => sub { exit(0); },
-        SDL_KEYDOWN() => 
-            sub { 
-                print "Ai\n"; 
-                if($play){
-                     $snd->pause;
-                     $play=0;
-                }else{
-                     $snd->resume;
-                     $play=1;
-                } 
-             },    
-);
-    
-$app->loop( \%actions );
+$app->add_event_handler( sub{
+		my $e = $_[0];
+		if( $e->type == SDL_KEYDOWN )
+		{ 
+		print "Ai\n"; 
+		if($play){
+		$snd->pause;
+		$play=0;
+		}else{
+		$snd->resume;
+		$play=1;
+		} 
+		}    
+		} );
 
+$app->run();
 
