@@ -123,9 +123,7 @@ sub get_pixel {
 
 sub set_pixel {
 	my ( $self, $y, $x, $new_value ) = @_;
-
 	$new_value = SDLx::Validate::num_rgba($new_value);
-
 	SDLx::Surface::set_pixel_xs( $self, $x, $y, $new_value );
 }
 
@@ -190,6 +188,8 @@ sub load {
 		}
 	}
 
+	
+	
 	my $formated_surface = $surface;
 	if( SDL::Video::get_video_surface )
 	{
@@ -201,6 +201,33 @@ sub load {
 
 #EXTENSTIONS
 
+sub blit {
+	my ( $src, $dest, $src_rect, $dest_rect ) = @_;
+
+	$src = SDLx::Validate::surface($src);
+	$dest = SDLx::Validate::surface($dest);
+
+	if(defined $src_rect) {
+		$src_rect = SDLx::Validate::rect($src_rect);
+	}
+	else {
+		$src_rect = SDL::Rect->new( 0, 0, $src->w, $src->h );
+	}
+	if(defined $dest_rect) {
+		$dest_rect = SDLx::Validate::rect($dest_rect);
+	}
+	else {
+		$dest_rect = SDL::Rect->new( 0, 0, $dest->w, $dest->h );
+	}
+
+	SDL::Video::blit_surface(
+		$src, $src_rect,
+		$dest, $dest_rect
+	);
+
+	return $src;
+}
+
 sub blit_by {
 	my ( $dest, $src, $src_rect, $dest_rect ) = @_;
 	SDLx::Surface::blit( $src, $dest, $src_rect, $dest_rect );
@@ -218,13 +245,13 @@ sub update {
 	my ( $surface, $rects ) = @_;
 
 	if ( !defined($rects) || ( ref($rects) eq 'ARRAY' && !ref( $rects->[0] ) ) ) {
-			my @rect;
-		 @rect = @{$rects} if $rects;
+		my @rect;
+		@rect = @{$rects} if $rects;
 		$rect[0] ||= 0;
 		$rect[1] ||= 0;
 		$rect[2] ||= $surface->w;
 		$rect[3] ||= $surface->h;
- 	
+		
 		SDL::Video::update_rect( $surface, @rect );
 	} else {
 		SDL::Video::update_rects( $surface, map { SDLx::Validate::rect($_) } @{$rects} );
@@ -233,6 +260,20 @@ sub update {
 	return $surface;
 }
 
+sub draw_rect {
+	my ( $self, $rect, $color ) = @_;
+	$color = SDLx::Validate::map_rgba( $color, $self->format );
+	if ( defined $rect ) {
+		$rect = SDLx::Validate::rect($rect);
+	} else {
+		$rect = SDL::Rect->new( 0, 0, $self->w, $self->h );
+	}
+
+	SDL::Video::fill_rect( $self, $rect, $color )
+		and Carp::confess "Error drawing rect: " . SDL::get_error();
+	return $self;
+}
+
 sub draw_line {
 	my ( $self, $start, $end, $color, $antialias ) = @_;
 
@@ -273,7 +314,7 @@ sub draw_circle {
 
 	unless( $antialias )
 	{
-		SDL::GFX::Primitives::circle_color( $self, @{$center}, $radius, $color );
+	SDL::GFX::Primitives::circle_color( $self, @{$center}, $radius, $color );
 	}
 	else
 	{
@@ -283,7 +324,7 @@ sub draw_circle {
 }
 
 sub draw_circle_filled {
-	my ( $self, $center, $radius, $color) = @_;
+	my ( $self, $center, $radius, $color ) = @_;
 
 	unless ( SDL::Config->has('SDL_gfx_primitives') ) {
 		Carp::cluck("SDL_gfx_primitives support has not been compiled");
@@ -298,37 +339,95 @@ sub draw_circle_filled {
 	return $self;
 }
 
-
 sub draw_trigon {
-	my ( $self, $center, $vextexes, $color ) = @_;
+	my ( $self, $vertices, $color, $antialias ) = @_;
+
+	$color = SDLx::Validate::num_rgba($color);
+
+	if ($antialias) {
+		SDL::GFX::Primitives::aatrigon_color( $self, $vertices->[0][0], $vertices->[0][1], $vertices->[1][0], $vertices->[1][1], $vertices->[2][0], $vertices->[2][1], $color );
+	}
+	else
+	{
+		SDL::GFX::Primitives::trigon_color( $self, $vertices->[0][0], $vertices->[0][1], $vertices->[1][0], $vertices->[1][1], $vertices->[2][0], $vertices->[2][1], $color );
+	}
+
+	return $self;
+}
+
+sub draw_trigon_filled {
+	my ( $self, $vertices, $color ) = @_;
+
+	$color = SDLx::Validate::num_rgba($color);
+
+	SDL::GFX::Primitives::filled_trigon_color( $self, $vertices->[0][0], $vertices->[0][1], $vertices->[1][0], $vertices->[1][1], $vertices->[2][0], $vertices->[2][1], $color );
+
+	return $self;
+}
+
+sub draw_polygon_filled {
+	my ( $self, $vertices, $color ) = @_;
+
+	$color = SDLx::Validate::num_rgba($color);
+
+	my @vx = map { $_->[0] } @$vertices;
+	my @vy = map { $_->[1] } @$vertices;
+	SDL::GFX::Primitives::filled_polygon_color( $self, \@vx, \@vy, scalar @$vertices, $color );
 
 	return $self;
 }
 
 sub draw_arc {
-	my ( $self, $vector, $radius, $start, $end, $color ) = @_;
+	my ( $self, $center, $radius, $start, $end, $color ) = @_;
+
+	Carp::cluck "Center needs to be an array of format [x,y]" unless ( ref $center eq 'ARRAY' && scalar @$center == 2 );
+	$color = SDLx::Validate::num_rgba($color);
+
+	SDL::GFX::Primitives::arc_color( $self, @$center, $radius, $start, $end, $color );
 
 	return $self;
 }
 
 sub draw_ellipse {
-	my ( $self, $center, $radius, $color, $antialias ) = @_;
+	my ( $self, $center, $rx, $ry, $color, $antialias ) = @_;
+
+	Carp::cluck "Center needs to be an array of format [x,y]" unless ( ref $center eq 'ARRAY' && scalar @$center == 2 );
+	$color = SDLx::Validate::num_rgba($color);
+
+	if ($antialias)
+	{
+		SDL::GFX::Primitives::aaellipse_color( $self, @$center, $rx, $ry, $color );
+	}
+	else
+	{
+		SDL::GFX::Primitives::ellipse_color( $self, @$center, $rx, $ry, $color );
+	}
 
 	return $self;
 }
 
-sub draw_polygon {
-	my ( $self, $vector, $color ) = @_;
+sub draw_ellipse_filled {
+	my ( $self, $center, $rx, $ry, $color ) = @_;
+
+	Carp::cluck "Center needs to be an array of format [x,y]" unless ( ref $center eq 'ARRAY' && scalar @$center == 2 );
+	$color = SDLx::Validate::num_rgba($color);
+
+	SDL::GFX::Primitives::filled_ellipse_color( $self, @$center, $rx, $ry, $color );
 
 	return $self;
-
 }
 
 sub draw_bezier {
 	my ( $self, $vector, $smooth, $color ) = @_;
 
-}
+	$color = SDLx::Validate::num_rgba($color);
 
+	my @vx = map { $_->[0] } @$vector;
+	my @vy = map { $_->[1] } @$vector;
+	SDL::GFX::Primitives::bezier_color( $self, \@vx, \@vy, scalar @$vector, $smooth, $color );
+
+	return $self;
+}
 
 sub draw_gfx_text {
 	my ( $self, $vector, $color, $text, $font ) = @_;
